@@ -122,7 +122,7 @@ ggdotplotstats <- function(data,
           x = {{ x }},
           test.value = test.value,
           bf.prior = bf.prior,
-          caption = caption,
+          top.text = caption,
           output = "caption",
           k = k
         )
