@@ -151,7 +151,7 @@ gghistostats <- function(data,
           x = {{ x }},
           test.value = test.value,
           bf.prior = bf.prior,
-          caption = caption,
+          top.text = caption,
           output = "caption",
           k = k
         )
@@ -284,8 +284,5 @@ gghistostats <- function(data,
 
   # if any additional modification needs to be made to the plot
   # this is primarily useful for grouped_ variant of this function
-  plot <- plot + ggplot.component
-
-  # return the final plot
-  return(plot)
+  plot + ggplot.component
 }
