@@ -3,14 +3,14 @@
 #' @description Pie charts for categorical data with statistical details
 #'   included in the plot as a subtitle.
 #'
-#' @param x,main The variable to use as the **rows** in the contingency table.
-#' @param y,condition The variable to use as the **columns** in the contingency
+#' @param x The variable to use as the **rows** in the contingency table.
+#' @param y The variable to use as the **columns** in the contingency
 #'   table. Default is `NULL`. If `NULL`, one-sample proportion test (a goodness
 #'   of fit test) will be run for the `x` variable. Otherwise an appropriate
 #'   association test will be run. This argument can not be `NULL` for
 #'   `ggbarstats` function.
-#' @param proportion.test Decides whether proportion test for `main` variable is
-#'   to be carried out for each level of `condition` (Default: `TRUE`).
+#' @param proportion.test Decides whether proportion test for `x` variable is
+#'   to be carried out for each level of `y` (Default: `TRUE`).
 #' @param perc.k Numeric that decides number of decimal places for percentage
 #'   labels (Default: `0`).
 #' @param label Character decides what information needs to be displayed
@@ -43,19 +43,8 @@
 #' @references
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/ggpiestats.html}
 #'
-#' @return Unlike a number of statistical softwares, `ggstatsplot` doesn't
-#'   provide the option for Yates' correction for the Pearson's chi-squared
-#'   statistic. This is due to compelling amount of Monte-Carlo simulation
-#'   research which suggests that the Yates' correction is overly conservative,
-#'   even in small sample sizes. As such it is recommended that it should not
-#'   ever be applied in practice (Camilli & Hopkins, 1978, 1979; Feinberg, 1980;
-#'   Larntz, 1978; Thompson, 1988).
-#'
-#'   For more about how the effect size measures and their confidence intervals
-#'   are computed, see `?rcompanion::cohenG`, `?rcompanion::cramerV`, and
-#'   `?rcompanion::cramerVFit`.
-#'
 #' @examples
+#' \donttest{
 #' # for reproducibility
 #' set.seed(123)
 #'
@@ -66,15 +55,15 @@
 #' ggstatsplot::ggpiestats(
 #'   data = mtcars,
 #'   x = vs,
-#'   y = cyl,
-#'   legend.title = "Engine"
+#'   y = cyl
 #' )
+#' }
 #' @export
 
 # defining the function
 ggpiestats <- function(data,
-                       main,
-                       condition = NULL,
+                       x,
+                       y = NULL,
                        counts = NULL,
                        ratio = NULL,
                        paired = FALSE,
@@ -83,7 +72,6 @@ ggpiestats <- function(data,
                        label.args = list(direction = "both"),
                        label.repel = FALSE,
                        conf.level = 0.95,
-                       nboot = 100L,
                        k = 2L,
                        proportion.test = TRUE,
                        perc.k = 0,
@@ -101,17 +89,11 @@ ggpiestats <- function(data,
                        palette = "Dark2",
                        ggplot.component = NULL,
                        output = "plot",
-                       x = NULL,
-                       y = NULL,
                        ...) {
 
   # ensure the variables work quoted or unquoted
-  main <- rlang::ensym(main)
-  condition <- if (!rlang::quo_is_null(rlang::enquo(condition))) rlang::ensym(condition)
-  x <- if (!rlang::quo_is_null(rlang::enquo(x))) rlang::ensym(x)
+  x <- rlang::ensym(x)
   y <- if (!rlang::quo_is_null(rlang::enquo(y))) rlang::ensym(y)
-  x <- x %||% main
-  y <- y %||% condition
   counts <- if (!rlang::quo_is_null(rlang::enquo(counts))) rlang::ensym(counts)
 
   # saving the column label for the 'x' variables
@@ -125,8 +107,6 @@ ggpiestats <- function(data,
     tidyr::drop_na(data = .) %>%
     as_tibble(.)
 
-  # =========================== converting counts ============================
-
   # untable the dataframe based on the count for each observation
   if (!rlang::quo_is_null(rlang::enquo(counts))) {
     data %<>%
@@ -138,19 +118,28 @@ ggpiestats <- function(data,
       )
   }
 
-  # ============================ percentage dataframe ========================
-
   # x and y need to be a factor for this analysis
   # also drop the unused levels of the factors
 
   # x
   data %<>% dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }})))
+  x_levels <- nlevels(data %>% dplyr::pull({{ x }}))[[1]]
 
   # y
   if (!rlang::quo_is_null(rlang::enquo(y))) {
     data %<>% dplyr::mutate(.data = ., {{ y }} := droplevels(as.factor({{ y }})))
+    y_levels <- nlevels(data %>% dplyr::pull({{ y }}))[[1]]
+
+    # TO DO: until one-way table is supported by `BayesFactor`
+    if (y_levels == 1L) bf.message <- FALSE
+  } else {
+    y_levels <- 0L
   }
 
+  # facting is happening only if both vars have more than one levels
+  facet <- ifelse(y_levels > 1L, TRUE, FALSE)
+  if (x_levels == 1L && isTRUE(facet)) proportion.test <- FALSE
+
   # ========================= statistical analysis ==========================
 
   # if subtitle with results is to be displayed
@@ -162,12 +151,8 @@ ggpiestats <- function(data,
           x = {{ x }},
           y = {{ y }},
           ratio = ratio,
-          nboot = nboot,
           paired = paired,
-          legend.title = legend.title,
           conf.level = conf.level,
-          conf.type = "norm",
-          bias.correct = TRUE,
           k = k
         ),
         error = function(e) NULL
@@ -176,16 +161,19 @@ ggpiestats <- function(data,
     # preparing Bayes Factor caption
     if (isTRUE(bf.message) && !is.null(subtitle)) {
       caption <-
-        bf_contingency_tab(
-          data = data,
-          x = {{ x }},
-          y = {{ y }},
-          sampling.plan = sampling.plan,
-          fixed.margin = fixed.margin,
-          prior.concentration = prior.concentration,
-          caption = caption,
-          output = "caption",
-          k = k
+        tryCatch(
+          expr = bf_contingency_tab(
+            data = data,
+            x = {{ x }},
+            y = {{ y }},
+            sampling.plan = sampling.plan,
+            fixed.margin = fixed.margin,
+            prior.concentration = prior.concentration,
+            top.text = caption,
+            output = "caption",
+            k = k
+          ),
+          error = function(e) NULL
         )
     }
   }
@@ -230,7 +218,7 @@ ggpiestats <- function(data,
   palette_message(
     package = package,
     palette = palette,
-    min_length = nlevels(data %>% dplyr::pull({{ x }}))[[1]]
+    min_length = x_levels
   )
 
   # creating the basic plot
@@ -265,7 +253,7 @@ ggpiestats <- function(data,
     )))
 
   # if facet_wrap *is* happening
-  if (!rlang::quo_is_null(rlang::enquo(y))) {
+  if (isTRUE(facet)) {
     p <- p + ggplot2::facet_wrap(facets = dplyr::vars({{ y }}))
   }
 
@@ -280,7 +268,7 @@ ggpiestats <- function(data,
   # ================ sample size + proportion test labels =================
 
   # adding labels with proportion tests
-  if (!rlang::quo_is_null(rlang::enquo(y)) && isTRUE(proportion.test)) {
+  if (isTRUE(facet) && isTRUE(proportion.test)) {
     p <- p +
       rlang::exec(
         .fn = ggplot2::geom_text,
