@@ -1,14 +1,5 @@
-
 # ----------------------- ipmisc -----------------------------------
 
-#' @export
-#' @importFrom ipmisc specify_decimal_p
-ipmisc::specify_decimal_p
-
-#' @export
-#' @importFrom ipmisc signif_column
-ipmisc::signif_column
-
 #' @export
 #' @importFrom ipmisc set_cwd
 ipmisc::set_cwd
@@ -31,7 +22,6 @@ ipmisc::`%$%`
 #' @importFrom ipmisc "%<-%"
 ipmisc::`%<-%`
 
-
 #' @export
 #' @importFrom ipmisc "%||%"
 ipmisc::`%||%`
