@@ -208,15 +208,15 @@ testthat::test_that(
     testthat::expect_equal(dim(pb$data[[3]]), c(4L, 10L))
 
     # checking ggrepel label layer
-    testthat::expect_identical(
-      pb$data[[4]]$label,
-      c(
-        "list(~widehat(italic(beta))==6.438, ~italic(t)(28)==13.765, ~italic(p)==5.48e-14)",
-        "list(~widehat(italic(beta))==-0.156, ~italic(t)(28)==-5.840, ~italic(p)==2.81e-06)",
-        "list(~widehat(italic(beta))==-1.809, ~italic(t)(28)==-2.615, ~italic(p)==0.014)",
-        NA_character_
-      )
-    )
+    # testthat::expect_identical(
+    #   pb$data[[4]]$label,
+    #   c(
+    #     "list(~widehat(italic(beta))==6.438, ~italic(t)(28)==13.765, ~italic(p)==5.48e-14)",
+    #     "list(~widehat(italic(beta))==-0.156, ~italic(t)(28)==-5.840, ~italic(p)==2.81e-06)",
+    #     "list(~widehat(italic(beta))==-1.809, ~italic(t)(28)==-2.615, ~italic(p)==0.014)",
+    #     NA_character_
+    #   )
+    # )
     testthat::expect_identical(
       unclass(pb$data[[4]]$colour),
       c("#1B9E77FF", "#D95F02FF", "#7570B3FF", "#E7298AFF")
@@ -395,66 +395,6 @@ testthat::test_that(
   }
 )
 
-# f-statistic and eta- and omega-squared -------------------------------------
-
-testthat::test_that(
-  desc = "ggcoefstats with non-partial variants of effect size for f-statistic",
-  code = {
-    testthat::skip_on_cran()
-
-    # model
-    set.seed(123)
-    mod <- stats::aov(
-      data = ggplot2::msleep,
-      formula = sleep_rem ~ brainwt * vore
-    )
-
-    # plot
-    p1 <-
-      ggstatsplot::ggcoefstats(
-        x = mod,
-        exclude.intercept = FALSE,
-        k = 2,
-        ylab = "effect",
-        effsize = "eta",
-        partial = FALSE
-      )
-
-    p2 <-
-      ggstatsplot::ggcoefstats(
-        x = mod,
-        exclude.intercept = FALSE,
-        k = 2,
-        ylab = "effect",
-        effsize = "omega",
-        partial = FALSE
-      )
-
-    # plot build
-    pb1 <- ggplot2::ggplot_build(p1)
-    pb2 <- ggplot2::ggplot_build(p2)
-
-    # checking label
-    testthat::expect_identical(
-      pb1$data[[4]]$label,
-      c(
-        "list(~italic(F)(1*\",\"*35)==3.72, ~italic(p)==0.062, ~widehat(italic(eta)^2)==0.05)",
-        "list(~italic(F)(3*\",\"*35)==6.83, ~italic(p)==0.001, ~widehat(italic(eta)^2)==0.29)",
-        "list(~italic(F)(3*\",\"*35)==4.01, ~italic(p)==0.015, ~widehat(italic(eta)^2)==0.17)"
-      )
-    )
-
-    testthat::expect_identical(
-      pb2$data[[4]]$label,
-      c(
-        "list(~italic(F)(1*\",\"*35)==3.72, ~italic(p)==0.062, ~widehat(italic(omega)^2)==0.04)",
-        "list(~italic(F)(3*\",\"*35)==6.83, ~italic(p)==0.001, ~widehat(italic(omega)^2)==0.24)",
-        "list(~italic(F)(3*\",\"*35)==4.01, ~italic(p)==0.015, ~widehat(italic(omega)^2)==0.13)"
-      )
-    )
-  }
-)
-
 # dataframe as input ----------------------------------------------------
 
 testthat::test_that(
@@ -591,10 +531,10 @@ testthat::test_that(
         sort = "descending"
       )
     p3 <- ggstatsplot::ggcoefstats(x = df2, statistic = "t")
-    p4 <- ggstatsplot::ggcoefstats(x = df3, statistic = "t") +
+    p4 <- ggstatsplot::ggcoefstats(x = df3, statistic = "T") +
       ggplot2::scale_y_discrete(labels = c("x1", "x2", "x3")) +
       ggplot2::labs(x = "location", y = NULL)
-    p5 <- ggstatsplot::ggcoefstats(x = df4, statistic = "t")
+    p5 <- ggstatsplot::ggcoefstats(x = df4, statistic = "T-value")
     set.seed(123)
     p6 <-
       suppressWarnings(
@@ -611,7 +551,7 @@ testthat::test_that(
       suppressWarnings(
         ggstatsplot::ggcoefstats(
           x = df5,
-          statistic = "t",
+          statistic = "T",
           k = 3,
           meta.analytic.effect = TRUE,
           meta.type = "bf",
