@@ -3,13 +3,13 @@ testthat::test_that(
   code = {
     testthat::skip_on_cran()
 
-    #--------------------- only main variable -------------------------------
+    #--------------------- only x variable -------------------------------
 
     ## expecting error
     testthat::expect_error(
       ggstatsplot::grouped_ggpiestats(
         data = mtcars,
-        main = cyl,
+        x = cyl,
         messages = FALSE
       )
     )
@@ -22,7 +22,7 @@ testthat::test_that(
       ggstatsplot::grouped_ggpiestats(
         data = mtcars,
         grouping.var = am,
-        main = "cyl",
+        x = "cyl",
         results.subtitle = FALSE,
         messages = FALSE
       )
@@ -30,7 +30,7 @@ testthat::test_that(
     what = "gg"
     ))
 
-    #------------------ both main and condition variables ------------------
+    #------------------ both x and y variables ------------------
 
     ## without counts
 
@@ -68,9 +68,9 @@ testthat::test_that(
       ggstatsplot::grouped_ggpiestats(
         data = as.data.frame(Titanic),
         grouping.var = Class,
-        main = Sex,
+        x = Sex,
         results.subtitle = FALSE,
-        condition = Survived,
+        y = Survived,
         counts = "Freq",
         messages = FALSE
       )
@@ -92,98 +92,25 @@ testthat::test_that(
     ls_results <-
       suppressWarnings(ggstatsplot::grouped_ggpiestats(
         data = dplyr::sample_frac(tbl = forcats::gss_cat, size = 0.1),
-        main = relig,
-        condition = marital,
+        x = relig,
+        y = marital,
         grouping.var = race,
         output = "subtitle",
         messages = FALSE
       ))
 
-    # tests
-    testthat::expect_equal(
-      ls_results,
-      list(
-        Other = ggplot2::expr(paste(
-          NULL,
-          chi["Pearson"]^2,
-          "(",
-          "40",
-          ") = ",
-          "40.27",
-          ", ",
-          italic("p"),
-          " = ",
-          "0.458",
-          ", ",
-          widehat(italic("V"))["Cramer"],
-          " = ",
-          "0.01",
-          ", CI"["95%"],
-          " [",
-          "-0.30",
-          ", ",
-          "-0.02",
-          "]",
-          ", ",
-          italic("n")["obs"],
-          " = ",
-          182L
-        )),
-        Black = ggplot2::expr(paste(
-          NULL,
-          chi["Pearson"]^
-            2,
-          "(",
-          "32",
-          ") = ",
-          "25.11",
-          ", ",
-          italic("p"),
-          " = ",
-          "0.801",
-          ", ",
-          widehat(italic("V"))["Cramer"],
-          " = ",
-          "0.00",
-          ", CI"["95%"],
-          " [",
-          "-0.17",
-          ", ",
-          "0.01",
-          "]",
-          ", ",
-          italic("n")["obs"],
-          " = ",
-          317L
-        )),
-        White = ggplot2::expr(paste(
-          NULL,
-          chi["Pearson"]^
-            2,
-          "(",
-          "52",
-          ") = ",
-          "109.65",
-          ", ",
-          italic("p"),
-          " = ",
-          "5.33e-06",
-          ", ",
-          widehat(italic("V"))["Cramer"],
-          " = ",
-          "0.09",
-          ", CI"["95%"],
-          " [",
-          "0.03",
-          ", ",
-          "0.10",
-          "]",
-          ", ",
-          italic("n")["obs"],
-          " = ",
-          1649L
-        ))
-      )
-    )
+    set.seed(123)
+    sexpr_results <-
+      suppressWarnings(statsExpressions::expr_contingency_tab(
+        data = dplyr::sample_frac(tbl = forcats::gss_cat, size = 0.1) %>%
+          dplyr::filter(race == "Other"),
+        x = relig,
+        y = marital,
+        output = "subtitle",
+        messages = FALSE
+      ))
+
+    # checking subtitle
+    testthat::expect_equal(ls_results$Other, sexpr_results)
   }
 )
